% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/biMM.1.0.0.R
\docType{class}
\name{biMM.data-class}
\alias{biMM.data}
\alias{biMM.data-class}
\title{Reference class for bivariate variance component analysis.}
\description{
Reference class for bivariate variance component analysis.
}
\section{Fields}{

\describe{
\item{\code{d}}{numeric vector, eigenvalues of relatedness (of Included).}

\item{\code{Inculded}}{logical vector, who are included in U and d.}

\item{\code{IndID}}{character vector, inds' IDs.}

\item{\code{nInd}}{integer, number of inds.}

\item{\code{nTraits}}{integer, number of traits.}

\item{\code{relatedness}}{numeric matrix, nInd x nInd GRM.}

\item{\code{traits}}{numeric matrix, nInd x nTraits.}

\item{\code{trait.cor}}{numeric matrix, correlation of traits.}

\item{\code{U}}{numeric matrix, eigenvectors of relatedness (of Included).}
}}
\section{Methods}{

\describe{
\item{\code{bivariate.heritability(trait.pairs, allow.impute = 0, allow.set.missing = 0,
  traits.for.imputation = 0, computation = TRUE, normalize = TRUE)}}{}

\item{\code{excludeInd(exclIDs, redo.cor = TRUE)}}{}

\item{\code{excludeTraits(exclTraits)}}{}

\item{\code{heritability(trait.names, allow.impute = 0, allow.set.missing = 0,
  traits.for.imputation = 0, computation = TRUE, normalize = TRUE)}}{}

\item{\code{minimum.set.of.relateds.to.exclude(related.pairs)}}{}

\item{\code{order.for.bivariate.heritability(trait.pairs = NULL, start.pair = NULL,
  allow.impute = 0, allow.set.missing = 0)}}{}

\item{\code{order.for.heritability(trait.names = NULL, start.trait = NULL,
  allow.impute = 0, allow.set.missing = 0)}}{}

\item{\code{printInds()}}{}

\item{\code{printTraits()}}{}

\item{\code{read.traits.grm(trait.filename = NULL, grm.filename = NULL)}}{}

\item{\code{relatedPairs(threshold)}}{}
}}
\section{bivariate.heritability(--args above--)}{

'trait.pairs', 2-column array naming the trait pairs in the order
they are to be analyzed.
'allow.impute', for at most how many individuals allows at least one
trait value to be imputed;
'allow.set.missing', for at most how many individuals allows the
trait values to be set missing;
'traits.for.imputation', at most how many traits are used to impute missing
values. For imputation, chooses traits by their absolute correlation from 'trait.cor'
to the trait to be imputed. Value of 0 (DEFAULT) corresponds to the mean value imputation;
'computation', if FALSE does not do the parameter estimation;
'normalize' if FALSE does not scale the traits. Always mean centers the traits.
OUTPUT: data.frame with variance components for the grm component
('Vg1', 'Vg2' and 'cor_g') and the environmental component ('Ve1', 'Ve2' and 'cor_e').
'cor' is the total correlation.
'new_eigen' is 1 if a eigen decomposition was done anew for the pair, otherwise 0.
}

\section{excludeInd(--args above--)}{

Excludes individuals from biMM.data object based on IDs in 'exclIDs'.
If 'redo.cor' is FALSE, then does not recompute the trait.cor matrix after the exclusions.
}

\section{excludeTraits(--args above--)}{

Excludes traits based on trait names given in 'exclTraits'.
}

\section{heritability(--args above--)}{

'trait.names', a vector naming the traits in the order
they are to be analyzed.
'allow.impute', for at most how many individuals allows the
trait value to be imputed;
'allow.set.missing', for at most how many individuals allows the
trait value to be set missing;
'traits.for.imputation', at most how many traits are used to impute missing
values. For imputation, chooses traits by their absolute correlation from 'trait.cor'
to the trait to be imputed. Value of 0 (DEFAULT) corresponds to the mean value imputation;
'computation', if FALSE does not do the parameter estimation;
'normalize' if FALSE does not scale the traits. Always mean centers the traits.
OUTPUT: data.frame with the variance for the grm component
('Vg') and the environmental component ('Ve'').
'new_eigen' is 1 if a eigen decomposition was done anew for the pair, otherwise 0.
}

\section{minimum.set.of.relateds.to.exclude(--args above--)}{

Finds an approximately minimum set of individuals that need to be excluded
so that at least one individual from each row of 'related.pairs' (2-column array of IDs)
is removed.
}

\section{order.for.bivariate.heritability(--args above--)}{

Finds an order of trait pairs for 'bivariate.heritability()' aiming to optimize the
number of eigendecompositions and trait value imputation/missingness.
If 'trait.pairs' is NULL then considers all pairs of 'traits', otherwise considers
the pairs given as rows of 'trait.pairs';
If 'start.pair' is NULL then goes through all possible values for the first pair, otherwise
starts from the pair given in 'start.pair' (a vector of 2 trait names);
'allow.impute' and 'allow.set.missing' are as for 'bivarite.heritability()' above.
}

\section{order.for.heritability(--args above--)}{

Finds an order of traits for 'heritability()' aiming to optimize the
number of eigendecompositions and trait value imputation/missingness.
If 'trait.names' is NULL then considers all 'traits', otherwise considers
the traits given in 'trait.names';
If 'start.trait' is NULL then goes through all possible values for the first trait, otherwise
starts from 'start.trait';
'allow.impute' and 'allow.set.missing' are as for 'heritability()' above.
}

\section{read.traits.grm(--args above--)}{

Reads traits and/or genetic relationship matrix (grm).
File format for trait file: First two columns must match .grm.id file's columns 1-2
and trait file must have a header. For example, PLINK's ped files are OK,
but GCTA's trait files are not since they do not have a header.
File formats for .grm and grm.id is like in GCTA software
(but not accepting GCTA binary format).
Accepts also gzipped grm and the '.gz' ending may or may not be included in
input 'grm.filename'
However, for the ID file, '.id' is always added to the input string 'grm.filename',
even if 'grm.filename' ends in '.gz'.
So typically 'grm.filename' should not have '.gz' ending in it.
}

\section{relatedPairs(--args above--)}{

Lists pairs of individuals whose 'relatedness' value is above the 'threshold'.
}

\section{Examples}{

x = biMM.data() ##Generate a new biMM.data object

Exclude a minimum set of individuals 
so that no pair with r>0.8 remains:

x$excludeInd(x$minimum.set.of.relateds.to.exclude(x$relatedPairs(0.8)))


Order traits for univariate heritability analysis:

tr.ord = x$order.for.heritability(allow.impute=20, allow.set.missing=30)


Compute univariate heritabilities:

x$heritability(tr.ord , allow.impute=20, allow.set.missing=30)


Order traits for bivariate heritability analysis:

tr.ord = x$order.for.bivariate.heritability(allow.impute=20, allow.set.missing=30)


Compute bivariate heritabilities:

x$bivariate.heritability(tr.ord , allow.impute=20, allow.set.missing=30)
}

