/*
##########################################################################
# biMM (1.0.0): An R package for a bivariate linear Mixed Model 
# DATE: 08-Nov-2016
# Copyright (C) 2016 University of Helsinki
# Software written by Matti Pirinen with help from Christian Benner.
# Contact: matti.pirinen@iki.fi
# LICENSE:
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 3 of the License, or
#   (at your option) any later version.
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#   You should have received a copy of the GNU General Public License
#   along with this program. If not, see <http://www.gnu.org/licenses/>.
#
##########################################################################
*/
#include <Rcpp.h>
using namespace Rcpp;

RcppExport SEXP list2matrix(SEXP vec_)
{
    NumericVector vec(vec_);
    
    int n_ind = (int) ((sqrt(8*vec.size()+1)-1)*0.5);
    NumericMatrix M(n_ind, n_ind);
    int index;
    
    for(int ii = 0; ii < n_ind; ii++)
    {
        for(int jj = 0; jj <= ii; jj++)
        {
            index = ii * (ii+1) / 2 + jj;
            M(ii, jj) = vec[index];
            M(jj, ii) = vec[index];
        }
    }
    
    return M; 
}

RcppExport SEXP HamiltonianPathForColumns(SEXP avail_, SEXP start_i_)
{
    LogicalMatrix avail(avail_);
    int start_i = as<int>(start_i_);
    
    int n_traits = avail.ncol();
    int n_inds = avail.nrow();
    NumericVector ord(n_traits);
    NumericVector remaining(n_traits);
    int ii_ord=0,min_val,min_i,jj,kk,s;
    
    
    for(int jj=0; jj<n_traits; ++jj){remaining(jj)=jj;} /*initialize*/
    
    /*Set the first choice to ord and remove from remaining*/
    ord(ii_ord) = start_i-1;
    remaining(ord(ii_ord))=remaining(n_traits-1-ii_ord); /*remaining will be used only btw 0,...,n_traits-1-ii_ord*/
    remaining(n_traits-1-ii_ord)=(-1);
    ii_ord++;
    
    while(ii_ord < n_traits){
        
        min_val = n_inds; /*initialize to absolute maximum*/
        min_i = -1; /*one of traits achieving minimum value*/
        
        for(jj=0; jj< n_traits-ii_ord; ){ /*goes through all remaining traits*/
            for(s=0,kk=0; kk<n_inds; ++kk)
                s += (int) (avail(kk,remaining(jj)) != avail(kk,ord(ii_ord-1)));
            
            if(s == 0){ /*add all those that have distance 0 right away*/
                ord(ii_ord) = remaining(jj);
                remaining(jj) = remaining(n_traits-1-ii_ord);
                remaining(n_traits-1-ii_ord) = -1;
                ii_ord++;
                /*Do not increase jj here!*/
            }else{ /*otherwise look for the one (of possibly many) that has min distance*/
                if(s < min_val) {min_val = s; min_i = jj;}
                ++jj;
            }
        }
        if(ii_ord == n_traits)
            break;
        
        ord(ii_ord) = remaining(min_i);
        remaining(min_i) = remaining(n_traits-1-ii_ord);
        remaining(n_traits-1-ii_ord) = -1;
        ii_ord++;
    }
    
    return wrap(ord+1);
}
